**Installation**
    `pip install middleware-active-directory`

Requires `middleware_test`

**Initialization**
    `active_directory_init` -- creates base ActiveDirectory class and record in db with system.
    You can override the common methods in class with own requests or use default ones.